@@ -45,14 +45,16 @@ def ensure_login(method):
             # Try to refresh token
             # Confirm it is a token invalid 401, registry not configured mistriggers this flow.
             if r.status_code == 401:
-                refresh_token(ctx)
+                data = r.json()
+                if "code" in data and data["code"].startswith("A0"):
+                    refresh_token(ctx)
 
-                # Refresh the context
-                c = read_config_dotfile()
-                ctx.obj.config = c
-                ctx.obj.profile = get_user_profile(c, ctx.obj.profile_name)
+                    # Refresh the context
+                    c = read_config_dotfile()
+                    ctx.obj.config = c
+                    ctx.obj.profile = get_user_profile(c, ctx.obj.profile_name)
 
-                r = method(*args, **kwargs)
+                    r = method(*args, **kwargs)
 
         return r
     return check_access_token
