@@ -65,7 +65,7 @@ def list_tags(
     tag_filter: str = typer.Option(None, "--tag-filter", "-t"),
 ):
     @ensure_login
-    def _request(ctx: typer.Context, tag_filter: str | None) -> httpx.Response:
+    def _request(ctx: typer.Context) -> httpx.Response:
         params = {}
         if tag_filter:
             params["tag_filter"] = tag_filter
@@ -74,7 +74,7 @@ def list_tags(
             params=params,
             headers=bearer(ctx),
         )
-    r = _request(ctx, tag_filter)
+    r = _request(ctx)
 
     process_response(r)
 
